Coriolis Network Ports Requirements

In order for Coriolis to be able to perform Replica/Migration tasks, it will require network access to the Endpoints that will be used. Once the network connection is available, Coriolis will use certain ports to further communicate with the Endpoints, as it is the intermediary between the source and destination Endpoints. No direct communication is established between the source and destination endpoints, all traffic and communication go through the Coriolis Appliance.

The following ports are the default for each endpoint, so the Cloud administrator must verify for any customized ports. For cloud access of the Endpoints, Coriolis will use the same ports even though the Endpoint will be used as the source or destination.

The temporary worker transfer mechanism for the destination platforms offers two options: HTTPS and SSH. The default one is the HTTPS-based transfer mechanism (TCP/5566) , which is faster but might not work if there are firewalls in the way. The SSH-based transfer mechanism (TCP/22) is more costly but will be allowed by most firewalls since SSH access from the Coriolis installation to the temporary worker VM is always required. Coriolis automatically sets security group rules for the temporary VMs accordingly.

Regarding the temporary migration worker for the source platforms, Coriolis uses Replicator port 4433 for performing disk chunking and transferring the backup data to the writer located on the destination platform. This port is used on platforms that require a migration worker machine.

OpenStack

Service

Default Port

Protocol

Keystone

5000

TCP

Cinder

8776

TCP

Nova

8774

TCP

Glance

9292

TCP

Neutron

9696

TCP

Swift

8080

TCP

Ceph

6789

TCP

Temporary Migration Worker - Source

22, 4433

TCP

Temporary Migration Worker - Destination

22

4433 5986

5566

TCP

VMware

Service

Default Port

Protocol

vSphere API Access (Management)

443

TCP

Temporary Migration Worker - Destination

22

4433 5986

5566

TCP

VM snapshot data transfer via NFC (to all ESXi nodes*)

902

TCP

  • NOTE! In the case of VMware vSphere as the source platform, Coriolis must be able to connect to all the VMware ESXi nodes, not only to the one holding the VM to be migrated. That is due to how VMware manages the data transfer, refer to the VMware plugin documentation for more details.

Amazon Web Services (AWS)

Service

Default Port

Protocol

Public API

80, 443

TCP

Temporary Migration Worker - Source

22, 4433

TCP

Temporary Migration Worker - Destination

22

4433 5986

5566

TCP

Microsoft Azure

Service

Default Port

Protocol

Public API

80, 443

TCP

Temporary Migration Worker - Source

22, 4433

TCP

Temporary Migration Worker - Destination

22

4433 5986

5566

TCP

Microsoft Windows Server - Hyper-V

Service

Default Port

Protocol

Management

443

TCP

RCT Source

6677

TCP

Oracle Cloud Infrastructure (OCI)

Service

Default Port

Protocol

Public API

80, 443

TCP

Temporary Migration Worker - Destination

22

5986

5566

TCP

oVirt (OLVM and Red Hat Virtualization)

Service

Default Port

Protocol

Public API

80, 443

TCP

Source Image Transfer

54322

TCP

Temporary Migration Worker - Destination

22

4433 5986

5566

TCP

SUSE Virtualization (Harvester)

Service

Default Port

Protocol

Kubernetes API

443

TCP

KubeVirt API

443

TCP

Temporary Migration Worker - Destination

22

5986

5566

TCP

SUSE Linux (KVM)

Service

Default Port

Protocol

SSH access for libvirt qemu+ssh transport

22

TCP

Temporary Migration Worker - Destination

22

5986

5566

TCP

Proxmox VE

Service

Default Port

Protocol

Management API

8006

TCP

Temporary Migration Worker - Destination

22

4433 5986

5566

TCP

CloudStack

Service

Default Port

Protocol

Management API

443

TCP

Temporary Migration Worker - Destination

22

4433 5986

5566

TCP

MicroCloud/LXD

Service

Default Port

Protocol

Management API

8443

TCP

Temporary Migration Worker - Destination

22

5986

5566

TCP

Bare-Metal (Linux p2v)

Service

Default Port

Protocol

Bare-metal Hub API

9900

TCP

Snapshot Agent API

9999

TCP

Nutanix

Service

Default Port

Protocol

Management API

9440

TCP

[Legacy] Oracle VM (OVM)

Service

Default Port

Protocol

Management

7002

TCP

Temporary Migration Worker - Source

22, 4433

TCP

Temporary Migration Worker - Destination

22

5986

5566

TCP

OVM Exporter

5544

TCP

[Legacy] Oracle Cloud Infrastructure Classic (OCI-C)

Service

Default Port

Protocol

Public API

80, 443

TCP

Temporary Migration Worker - Source

22, 4433

TCP

Temporary Migration Worker - Destination

22, 5986

TCP

Coriolis API/CLI remote access

When accessing the Coriolis API or CLI from a remote / client machine, the following ports have to be allowed for the Coriolis appliance network. Additional ports are required when scaling out Coriolis with additional Coriolis worker machines:

Service

Default Port

Protocol

Coriolis API

7667

TCP

Coriolis API - Keystone

5000

TCP

Barbican

9311

TCP

Metal Hub API - required only for Linux p2v

9900

TCP

Coriolis Licensing

37667

TCP

Coriolis Logging

9998

TCP